package Acme::MirrorTracer;

use warnings;
use strict;

=head1 NAME

Acme::MirrorTracer - Do nothing.

=head1 VERSION

This document describes Acme::MirrorTracer version 2009.051914390009

=cut

our $VERSION = '2009.051914390009';

=head1 DESCRIPTION

How quickly does this get propagated by CPAN mirrors?

=cut

1;
__END__

=head1 DEPENDENCIES

None.

=head1 BUGS AND LIMITATIONS

No bugs have been reported.

Please report any bugs or feature requests to
C<bug-acme-mirrortracer@rt.cpan.org>, or through the web interface at
L<http://rt.cpan.org>.

=head1 AUTHOR

Andy Armstrong  C<< <andy@hexten.net> >>

=head1 LICENCE AND COPYRIGHT

Copyright (c) 2009, Andy Armstrong C<< <andy@hexten.net> >>.

This module is free software; you can redistribute it and/or
modify it under the same terms as Perl itself. See L<perlartistic>.
